@@ -102,6 +102,11 @@ def create_new_file(
         permissions=permissions, response=response
     )
 
+    if not os.path.exists(os.path.dirname(file_path)):
+        response = create_new_directory(dir_path=os.path.dirname(file_path))
+        if not response.ok:
+            return response
+
     if response.ok:
         if file_name:
             response = utils._validate_path(path_obj=file_name, response=response)
@@ -254,6 +259,11 @@ def write_file(
         response.ok, response.log_level = False, "error"
         response.message = ValueError(f"File mode '{mode}' is not supported")
 
+    if not os.path.exists(os.path.dirname(file_path)):
+        response = create_new_directory(dir_path=os.path.dirname(file_path))
+        if not response.ok:
+            return response
+
     extension = ""
     if ext_override:
         extension = ext_override
